@@ -968,7 +968,7 @@ class TablasVC(SQLConnector):
             self.__consultar_incidencias(mensajes=mensajes,fecha_i=fecha_i,fecha_f=fecha_f)
             self.__crear_backup_de_las_tablas(datos_basicos=False,incidencias=True)
             
-    def modificar_incidencia(self,id,**kwargs):
+    def modificar_incidencia(self,id_inc,**kwargs):
         
         if self.incidencias_todas is None:
             raise Exception(f'No se han cargado incidencias aún.')
@@ -977,9 +977,9 @@ class TablasVC(SQLConnector):
         if vars_invalidas:
             raise KeyError(f'Las variables {vars_invalidas} no se encontraron en las columnas del DataFrame de incidencias {self.incidencias_todas.columns.to_list()}')
         
-        if not self.incidencias_todas.query(f'ID == {id}').empty:
+        if not self.incidencias_todas.query(f'ID == {id_inc}').empty:
             for k,v in kwargs.items():
-                self.incidencias_todas.loc[self.incidencias_todas.ID.eq(id), k] = v
-                self.incidencias_todas_auditoria.loc[self.incidencias_todas_auditoria.ID.eq(id), k] = v
+                self.incidencias_todas.loc[self.incidencias_todas.ID.eq(id_inc), k] = v
+                self.incidencias_todas_auditoria.loc[self.incidencias_todas_auditoria.ID.eq(id_inc), k] = v
         else:
-            raise ValueError(f'No se encontró la incidencia con ID {id}')
\ No newline at end of file
+            raise ValueError(f'No se encontró la incidencia con ID {id_inc}')
\ No newline at end of file
